<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>DialogAbout</name>
    <message>
        <location filename="../dialogabout.ui" line="14"/>
        <source>About IMSProg</source>
        <translation>Sobre IMSProg</translation>
    </message>
    <message>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, and M95xx series chips.</source>
        <translation type="vanished">IMSProg - software livre I2C, SPI e MicroWire EEPROM/Flash chip programador para dispositivos CH341a. IMSProg admite chips das séries 24Cxx, 25xx, 93Cxx e M95xx.</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="70"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;In this program &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; widget and modified programmer &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; were used.&lt;/p&gt;&lt;p&gt;The page on GitHub is &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;here&lt;/a&gt;, the support page is &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;here&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Neste programa utilizou-se o widget &lt;a href=&quot;https://github.com/Simsys/qhexedit2/&quot;&gt;QhexEditor2&lt;/a&gt; e o programador &lt;a href=&quot;https://github.com/McMCCRU/SNANDer&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;SNANDer&lt;/span&gt;&lt;/a&gt; modificado.&lt;/p&gt;&lt;p&gt;A página do GitHub está &lt;a href=&quot;https://github.com/bigbigmdm/IMSProg&quot;&gt;aqui&lt;/a&gt;, e a página de suporte está &lt;a href=&quot;https://antenna-dvb-t2.ru/IMSProg.php&quot;&gt;aqui&lt;/a&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="120"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="130"/>
        <source>1.1.4</source>
        <translation>1.1.4</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="48"/>
        <source>OR</source>
        <translation>OU</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="26"/>
        <source>IMSProg - free software I2C, SPI and MicroWire EEPROM/Flash chip programmer for CH341a devices. IMSProg supports 24Cxx, 25xx, 93Cxx, AT45DBxx and M95xx series chips.</source>
        <translation>IMSProg - software livre I2C, SPI e MicroWire EEPROM/Flash chip programador para dispositivos CH341a. IMSProg admite chips das séries 24Cxx, 25xx, 93Cxx, AT45DBxx e M95xx.</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="99"/>
        <source>Written by 2023 Mikhail Medvedev</source>
        <translation>Escrito por Mikhail Medvedev 2023</translation>
    </message>
    <message>
        <location filename="../dialogabout.ui" line="169"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../dialoginfo.ui" line="14"/>
        <source>Connection info:</source>
        <translation>Informação de conexão:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="36"/>
        <source>Slot:</source>
        <translation>Slot:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="43"/>
        <location filename="../dialoginfo.ui" line="61"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="54"/>
        <source>Adapter:</source>
        <translation>Adaptador:</translation>
    </message>
    <message>
        <location filename="../dialoginfo.ui" line="106"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>DialogRP</name>
    <message>
        <location filename="../dialogrp.ui" line="20"/>
        <source>Load block from file</source>
        <translation>Carregar bloco de arquivo</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="33"/>
        <source>All values in HEX format!</source>
        <translation>Todos os valores em formato HEX!</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="48"/>
        <source>Start address:</source>
        <translation>Endereço de início:</translation>
    </message>
    <message>
        <location filename="../dialogrp.ui" line="112"/>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
</context>
<context>
    <name>DialogSFDP</name>
    <message>
        <location filename="../dialogsfdp.ui" line="14"/>
        <source>Information about SFDP and status registers</source>
        <translation>Informações sobre SFDP e registros de status</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="47"/>
        <source>SFDP support:</source>
        <translation>Suporte SFDP:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="67"/>
        <source>Minimum VCC:</source>
        <translation>VCC mínimo:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="87"/>
        <source>Maximum VCC:</source>
        <translation>VCC máximo:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="107"/>
        <source>Chip size:</source>
        <translation>Tamanho do chip:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="127"/>
        <source>Block size:</source>
        <translation>Tamanho do bloco:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="150"/>
        <source>Speeds:</source>
        <translation>Velocidades:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="170"/>
        <source>OTP support:</source>
        <translation>Suporte OTP:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="196"/>
        <source>Status Register 0</source>
        <translation>Registro de status 0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="424"/>
        <source>SPR0</source>
        <translation>SPR0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="449"/>
        <source>BP4</source>
        <translation>BP4</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="474"/>
        <source>BP3</source>
        <translation>BP3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="499"/>
        <source>BP2</source>
        <translation>BP2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="524"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="549"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="574"/>
        <source>WEL</source>
        <translation>WEL</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="599"/>
        <source>WIP</source>
        <translation>WIP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="830"/>
        <source>SUS1</source>
        <translation>SUS1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="855"/>
        <source>CMP</source>
        <translation>CMP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="880"/>
        <source>LB3</source>
        <translation>LB3</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="905"/>
        <source>LB2</source>
        <translation>LB2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="930"/>
        <source>LB1</source>
        <translation>LB1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="955"/>
        <source>SUS2</source>
        <translation>SUS2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="980"/>
        <source>QE</source>
        <translation>QE</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1005"/>
        <source>SPR1</source>
        <translation>SPR1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="611"/>
        <source>Status Register 1</source>
        <translation>Registro de status 1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1017"/>
        <source>Status register 2</source>
        <translation>Registro de status 2</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1195"/>
        <source>JEDEC info:</source>
        <translation>Informações JEDEC:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1301"/>
        <source>Man. ID</source>
        <translation>ID Fabr.</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1323"/>
        <source>Man. type</source>
        <translation>Tipo Fabr.</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1345"/>
        <source>Capacity</source>
        <translation>Capacidade</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1357"/>
        <source>Unique ID:</source>
        <translation>ID único:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1398"/>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1426"/>
        <source>Write registers</source>
        <translation>Gravar registros</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1453"/>
        <location filename="../dialogsfdp.ui" line="1519"/>
        <location filename="../dialogsfdp.ui" line="1541"/>
        <source>(R)</source>
        <translation>(R)</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1475"/>
        <source>DRV1</source>
        <translation>DRV1</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1497"/>
        <source>DRV0</source>
        <translation>DRV0</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1563"/>
        <source>WPS</source>
        <translation>WPS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1585"/>
        <source>ADP</source>
        <translation>ADP</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1607"/>
        <source>ADS</source>
        <translation>ADS</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1693"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p/&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1731"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Legend:&lt;/p&gt;&lt;p&gt;** - Basic area&lt;br&gt;** - Extended area&lt;br&gt;** - Manufacture area &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;body&gt;&lt;p&gt;Legenda:&lt;/p&gt;&lt;p&gt;** - Zona básica&lt;br&gt;** - Zona ampliada&lt;br&gt;** - Zona de fabricação&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.ui" line="1776"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="99"/>
        <location filename="../dialogsfdp.cpp" line="208"/>
        <location filename="../dialogsfdp.cpp" line="228"/>
        <location filename="../dialogsfdp.cpp" line="254"/>
        <source>Error reading register!</source>
        <translation>Erro ao ler o registro!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="171"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Hex SFDP register data:
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Dados de registro hexadecimal SFDP:
</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="172"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Addr:&lt;br&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Addr:&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="417"/>
        <source>Before writing the registers, please press the `Read` button!</source>
        <translation>Antes de escrever os registros, favor pressionar o botão `Ler`!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="79"/>
        <source>Error reading JEDEC ID!</source>
        <translation>Erro ao ler o ID JEDEC!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="39"/>
        <source>Legend:</source>
        <translation>Legenda:</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="40"/>
        <source> - Basic area</source>
        <translation> - Zona básica</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="41"/>
        <source> - Extended area</source>
        <translation> - Zona ampliada</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="42"/>
        <source> - Manufacture area</source>
        <translation> - Zona de fabricação</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="283"/>
        <source>Error reading unique ID!</source>
        <translation>Erro ao ler o ID único!</translation>
    </message>
    <message>
        <location filename="../dialogsfdp.cpp" line="298"/>
        <location filename="../dialogsfdp.cpp" line="415"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>O programador CH341a não está conectado!</translation>
    </message>
</context>
<context>
    <name>DialogSP</name>
    <message>
        <location filename="../dialogsp.ui" line="14"/>
        <source>Save part of image</source>
        <translation>Salvar parte da imagem</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="27"/>
        <source>All values in HEX format!</source>
        <translation>Todos os valores em formato HEX!</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="42"/>
        <source>Start address:</source>
        <translation>Endereço de início:</translation>
    </message>
    <message>
        <location filename="../dialogsp.ui" line="120"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="27"/>
        <source>End address</source>
        <translation>Endereço final</translation>
    </message>
    <message>
        <location filename="../dialogsp.cpp" line="28"/>
        <source>Length</source>
        <translation>Comprimento</translation>
    </message>
</context>
<context>
    <name>DialogSR</name>
    <message>
        <location filename="../dialogsr.ui" line="14"/>
        <source>Status register</source>
        <translation>Registro de status</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="296"/>
        <source>WPEN</source>
        <translation>WPEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="327"/>
        <location filename="../dialogsr.ui" line="358"/>
        <location filename="../dialogsr.ui" line="389"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="420"/>
        <source>BP1</source>
        <translation>BP1</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="451"/>
        <source>BP0</source>
        <translation>BP0</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="482"/>
        <source>WEN</source>
        <translation>WEN</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="513"/>
        <source>/RDY</source>
        <translation>/RDY</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="545"/>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <location filename="../dialogsr.ui" line="567"/>
        <source>Write</source>
        <translation>Programar</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="54"/>
        <location filename="../dialogsr.cpp" line="68"/>
        <location filename="../dialogsr.cpp" line="107"/>
        <location filename="../dialogsr.cpp" line="110"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="54"/>
        <source>Error reading register!</source>
        <translation>Erro ao ler o registro!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="68"/>
        <location filename="../dialogsr.cpp" line="110"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>O programador CH341a não está conectado!</translation>
    </message>
    <message>
        <location filename="../dialogsr.cpp" line="107"/>
        <source>Before writing the register, please press the `Read` button!</source>
        <translation>Antes de escrever os registro, favor pressionar o botão `Ler`!</translation>
    </message>
</context>
<context>
    <name>DialogSetAddr</name>
    <message>
        <location filename="../dialogsetaddr.ui" line="14"/>
        <source>Goto address</source>
        <translation>Ir para o endereço</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="24"/>
        <source>All values in HEX format!</source>
        <translation>Todos os valores em formato HEX!</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="39"/>
        <source>Address:</source>
        <translation>Endereço:</translation>
    </message>
    <message>
        <location filename="../dialogsetaddr.ui" line="90"/>
        <source>Go to</source>
        <translation>Ir para</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="893"/>
        <source>File</source>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="985"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="988"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Exit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="997"/>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>IMSProg - I2C/MicroWire/SPI CH341a Programmer</source>
        <translation>IMSProg - Programador I2C/MicroWire/SPI CH341a</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="77"/>
        <source>Chip</source>
        <translation>Chip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="247"/>
        <source>Page size</source>
        <translation>Tamanho de página</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <source>Block size</source>
        <translation>Tamanho do bloco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>VCC, Volt</source>
        <translation>VCC, Volts</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>4bit Addr.</source>
        <translation>Endereço 4bits.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Detect</source>
        <translation>Detectar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <location filename="../mainwindow.ui" line="1033"/>
        <source>Read</source>
        <translation>Ler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>i</source>
        <translation>i</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Auto Options</source>
        <translation>Opções automáticas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="1045"/>
        <source>Erase</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="604"/>
        <source>Program</source>
        <translation>Programar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Verify</source>
        <translation>Verificar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <source>Go!</source>
        <translation>Ir!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <location filename="../mainwindow.ui" line="923"/>
        <source>Hex Editor</source>
        <translation>Editor hexadecimal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="770"/>
        <source>  JEDEC ID:</source>
        <translation>JEDEC ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>CH341a:</source>
        <translation>CH341a:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="811"/>
        <source>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</source>
        <translation>border: 2px solid gray;border-radius: 5px;font-weight:600;border-style:inset;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="824"/>
        <source>CRC32:</source>
        <translation>CRC32:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="911"/>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1000"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1024"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1036"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1048"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1057"/>
        <source>Write</source>
        <translation>Programar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1072"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1081"/>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1084"/>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1093"/>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1096"/>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1206"/>
        <source>Import from Intel HEX</source>
        <translation>Importar de Intel HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1215"/>
        <source>Export to Intel HEX</source>
        <translation>Exportar para Intel HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <source>Extract from ASUS CAP</source>
        <translation>Extrair do CAP da ASUS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Goto address</source>
        <translation>Ir para o endereço</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1236"/>
        <source>Move the cursor to the entered address</source>
        <translation>Mova o cursor para o endereço inserido</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1239"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1105"/>
        <source>Save Part</source>
        <translation>Salvar Parte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Load Part</source>
        <translation>Carregar parte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1129"/>
        <source>Find / Replace</source>
        <translation>Localizar / Substituir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1132"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1137"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>About IMSProgrammer</source>
        <translation>Sobre IMSProgrammer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1143"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>Checksum calculate</source>
        <translation>Cálculo de Checksum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1155"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1164"/>
        <source>Edit chips Database</source>
        <translation>Editar banco de dados de chips</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1167"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1176"/>
        <location filename="../mainwindow.cpp" line="1581"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1179"/>
        <source>Forced stop of read, write, erase and verification operations</source>
        <translation>Parada forçada de operações de leitura, gravação, apagamento e verificação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1182"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1191"/>
        <source>Chip info</source>
        <translation>Informações do chip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1194"/>
        <source>Information about SFDP and status registers</source>
        <translation>Informações sobre SFDP e registros de status</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="754"/>
        <location filename="../mainwindow.cpp" line="794"/>
        <location filename="../mainwindow.cpp" line="1251"/>
        <location filename="../mainwindow.cpp" line="1950"/>
        <location filename="../mainwindow.cpp" line="2018"/>
        <source>Current file: </source>
        <translation>Arquivo atual: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Manufacture</source>
        <translation>Fabricação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1630"/>
        <source>Opening DAT file</source>
        <translation>Abrindo um arquivo DAT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="251"/>
        <location filename="../mainwindow.cpp" line="262"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="645"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <location filename="../mainwindow.cpp" line="762"/>
        <location filename="../mainwindow.cpp" line="798"/>
        <location filename="../mainwindow.cpp" line="894"/>
        <location filename="../mainwindow.cpp" line="903"/>
        <location filename="../mainwindow.cpp" line="910"/>
        <location filename="../mainwindow.cpp" line="931"/>
        <location filename="../mainwindow.cpp" line="941"/>
        <location filename="../mainwindow.cpp" line="1116"/>
        <location filename="../mainwindow.cpp" line="1125"/>
        <location filename="../mainwindow.cpp" line="1131"/>
        <location filename="../mainwindow.cpp" line="1141"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <location filename="../mainwindow.cpp" line="1166"/>
        <location filename="../mainwindow.cpp" line="1180"/>
        <location filename="../mainwindow.cpp" line="1209"/>
        <location filename="../mainwindow.cpp" line="1232"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1493"/>
        <location filename="../mainwindow.cpp" line="1639"/>
        <location filename="../mainwindow.cpp" line="2037"/>
        <location filename="../mainwindow.cpp" line="2069"/>
        <location filename="../mainwindow.cpp" line="2087"/>
        <location filename="../mainwindow.cpp" line="2107"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1209"/>
        <source>The end address must be greater than the starting address.</source>
        <translation>O endereço final deve ser maior que o endereço inicial.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1493"/>
        <source>File &apos;IMSProg_editor&apos; not found!</source>
        <translation>Arquivo não encontrado `IMSProg_editor`!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1639"/>
        <source>Error loading chip database file!</source>
        <translation>Erro ao carregar o arquivo de banco de dados do chip!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1645"/>
        <source>Parsing DAT file</source>
        <translation>Analisando arquivo DAT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Reading data from </source>
        <translation>Lendo dados de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <location filename="../mainwindow.cpp" line="894"/>
        <location filename="../mainwindow.cpp" line="1116"/>
        <source>Unsupported chip type!</source>
        <translation>Chip não suportado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="262"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="903"/>
        <location filename="../mainwindow.cpp" line="941"/>
        <location filename="../mainwindow.cpp" line="1125"/>
        <location filename="../mainwindow.cpp" line="1180"/>
        <source>Programmer CH341a is not connected!</source>
        <translation>O programador CH341a não está conectado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <location filename="../mainwindow.cpp" line="1131"/>
        <source>Error reading block </source>
        <translation>Erro ao ler o bloco </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="931"/>
        <location filename="../mainwindow.cpp" line="1165"/>
        <source>Before reading from chip please press &apos;Detect&apos; button.</source>
        <translation>Antes de ler o chip, clique no botão &apos;Detectar&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Please select the chip parameters - manufacture and chip name</source>
        <translation>Selecione os parâmetros do chip - Fabricante e nome do chip</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>The chip is not connect or missing!</source>
        <translation>Chip não conectado ou ausente!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <location filename="../mainwindow.cpp" line="1942"/>
        <source>Saving file</source>
        <translation>Salvando arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <location filename="../mainwindow.cpp" line="1944"/>
        <source>Save file</source>
        <translation>Salvar arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1232"/>
        <source>Error saving file!</source>
        <translation>Erro salvando arquivo!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Erasing the </source>
        <translation>Apagando o </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="645"/>
        <location filename="../mainwindow.cpp" line="696"/>
        <source>Error erasing sector </source>
        <translation>Erro apagando setor </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="788"/>
        <location filename="../mainwindow.cpp" line="2012"/>
        <source>Opening file</source>
        <translation>Abrindo arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="746"/>
        <location filename="../mainwindow.cpp" line="790"/>
        <location filename="../mainwindow.cpp" line="2014"/>
        <source>Open file</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="762"/>
        <location filename="../mainwindow.cpp" line="798"/>
        <source>The file size exceeds the chip size. Please select another chip or file or use `Save part` to split the file.</source>
        <translation>O tamanho do arquivo excede o tamanho do chip. Selecione outro chip ou arquivo ou use `Salvar Parte` para dividir o arquivo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2037"/>
        <source>Not valid HEX format!</source>
        <translation>O formato HEX não é válido!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2069"/>
        <source>The address is larger than the size of the chip!</source>
        <translation>O endereço é maior do que o tamanho do chip!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <location filename="../mainwindow.cpp" line="2107"/>
        <source>Checksum error!</source>
        <translation>Erro de checksum!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>Writing data to </source>
        <translation>Escrevendo dados em </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Error writing sector </source>
        <translation>Erro ao escrever o setor </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1086"/>
        <source>Veryfing data from </source>
        <translation>Verificando dados de </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1141"/>
        <source>Error comparing data!
Address:   </source>
        <translation>Erro ao comparar dados!
Endereço:   </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1141"/>
        <source>
Buffer: </source>
        <translation>
Buffer: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1141"/>
        <source>    Chip: </source>
        <translation>    Chip: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1166"/>
        <source>Please select the chip parameters - manufacture and chip name.</source>
        <translation>Selecione os parâmetros do chip - Fabricante e nome do chip.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>Ok!</source>
        <translation>Ok!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1175"/>
        <source>The operation was successful!</source>
        <translation>Operação concluida com êxito!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1221"/>
        <source>Saving block</source>
        <translation>Salvando bloco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1223"/>
        <source>Save block</source>
        <translation>Salvar bloco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Opening block</source>
        <translation>Abrindo bloco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1248"/>
        <source>Open block</source>
        <translation>Bloco aberto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1265"/>
        <source>The end address out of image size!</source>
        <translation>Endereço final fora do tamanho da imagem!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1304"/>
        <source>Connected</source>
        <translation>Conectado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1309"/>
        <source>Not connected</source>
        <translation>Não conectado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1581"/>
        <source>Operation aborted!</source>
        <translation>Operação abortada!</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../searchdialog.ui" line="14"/>
        <source>QHexEdit - Find/Replace</source>
        <translation>QHexEdit - Buscar/Substituir</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="26"/>
        <source>Find</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="33"/>
        <location filename="../searchdialog.ui" line="78"/>
        <source>Hex</source>
        <translation>Hex</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="38"/>
        <location filename="../searchdialog.ui" line="83"/>
        <source>UTF-8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="71"/>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="116"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="122"/>
        <source>&amp;Backwards</source>
        <translation>Voltar ao início</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="129"/>
        <source>&amp;Prompt on replace</source>
        <translation>Perguntar ao substituir</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="150"/>
        <source>Standard headers:</source>
        <translation>Cabeçalhos padrão:</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="191"/>
        <source>ZIP</source>
        <translation>ZIP</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="213"/>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="235"/>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="257"/>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="286"/>
        <source>TAR</source>
        <translation>TAR</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="308"/>
        <source>UEFI</source>
        <translation>UEFI</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="330"/>
        <source>BIOS</source>
        <translation>BIOS</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="352"/>
        <source>GPT</source>
        <translation>GPT</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="385"/>
        <source>&amp;Find</source>
        <translation>Encontrar</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="388"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="413"/>
        <source>&amp;Replace</source>
        <translation>Substituir</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="435"/>
        <source>Replace &amp;All</source>
        <translation>Substituir tudo</translation>
    </message>
    <message>
        <location filename="../searchdialog.ui" line="457"/>
        <source>&amp;Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <location filename="../searchdialog.cpp" line="113"/>
        <source>QHexEdit</source>
        <translation>QHexEdit</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="87"/>
        <source>%1 occurrences replaced.</source>
        <translation>%1 ocorrências substituídas.</translation>
    </message>
    <message>
        <location filename="../searchdialog.cpp" line="114"/>
        <source>Replace occurrence?</source>
        <translation>Substituir ocorrência?</translation>
    </message>
</context>
<context>
    <name>UndoStack</name>
    <message>
        <location filename="../commands.cpp" line="130"/>
        <source>Inserting %1 bytes</source>
        <translation>Inserir %1 bytes</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="152"/>
        <source>Delete %1 chars</source>
        <translation>Deletar %1 caracteres</translation>
    </message>
    <message>
        <location filename="../commands.cpp" line="177"/>
        <source>Overwrite %1 chars</source>
        <translation>Substituir %1 caracteres</translation>
    </message>
</context>
</TS>
